@@ -8,7 +8,7 @@ import re
 from kola import safe_call, logger
 
 
-def reader_counter(func):
+def count_reader(func):
     @functools.wraps(func)
     def func_wrapper(stream, *args, **kwargs):
         try:
@@ -20,7 +20,7 @@ def reader_counter(func):
     return func_wrapper
 
 
-def writer_counter(func):
+def count_writer(func):
     @functools.wraps(func)
     def func_wrapper(stream, *args, **kwargs):
         try:
@@ -86,7 +86,7 @@ class Stream(object):
         """
         self._close_callback = callback
 
-    @reader_counter
+    @count_reader
     def read_until_regex(self, regex, callback):
         """Run ``callback`` when we read the given regex pattern.
 
@@ -100,7 +100,7 @@ class Stream(object):
             if self._try_inline_read() <= 0:
                 break
 
-    @reader_counter
+    @count_reader
     def read_until(self, delimiter, callback):
         """
         为了兼容调用的方法
@@ -113,7 +113,7 @@ class Stream(object):
             if self._try_inline_read() <= 0:
                 break
 
-    @reader_counter
+    @count_reader
     def read_bytes(self, num_bytes, callback, streaming_callback=None):
         """Run callback when we read the given number of bytes.
 
@@ -131,7 +131,7 @@ class Stream(object):
             if self._try_inline_read() <= 0:
                 break
 
-    @reader_counter
+    @count_reader
     def read_until_close(self, callback, streaming_callback=None):
         """Reads all data from the socket until it is closed.
 
@@ -162,7 +162,7 @@ class Stream(object):
             if self._try_inline_read() < 0:
                 break
 
-    @writer_counter
+    @count_writer
     def write(self, data, callback=None):
         """
         写数据
